from django.core.management import call_command, CommandError
from arkindex.project.tests import FixtureTestCase
from arkindex.documents.models import ElementType


class TestMergeTypesCommand(FixtureTestCase):

    def test_merge_types_missing_source(self):
        with self.assertRaisesMessage(CommandError, 'Source type 404 not found in Unit Tests'):
            call_command('merge_types', corpus=self.corpus, source='404', destination='page')

    def test_merge_types_missing_destination(self):
        with self.assertRaisesMessage(CommandError, 'Destination type 404 not found in Unit Tests'):
            call_command('merge_types', corpus=self.corpus, source='page', destination='404')

    def test_merge_types_distinct(self):
        with self.assertRaisesMessage(CommandError, 'Source and destination types cannot be the same'):
            call_command('merge_types', corpus=self.corpus, source='page', destination='page')

    def test_merge_types(self):
        page_type = self.corpus.types.get(slug='page')
        surface_type = self.corpus.types.get(slug='surface')
        self.assertEqual(self.corpus.elements.filter(type=page_type).count(), 6)
        self.assertEqual(self.corpus.elements.filter(type=surface_type).count(), 6)

        with self.assertNumQueries(11):
            call_command('merge_types', corpus=self.corpus, source='surface', destination='page')

        self.assertEqual(self.corpus.elements.filter(type=page_type).count(), 12)
        self.assertFalse(self.corpus.elements.filter(type=surface_type).exists())
        with self.assertRaises(ElementType.DoesNotExist):
            surface_type.refresh_from_db()
