from django.urls import reverse
from rest_framework import status
from arkindex.documents.models import Corpus
from arkindex.project.tests import FixtureAPITestCase


class TestDestroyElements(FixtureAPITestCase):

    @classmethod
    def setUpTestData(cls):
        super().setUpTestData()
        cls.volume_type = cls.corpus.types.get(slug='volume')
        cls.vol = cls.corpus.elements.get(name='Volume 1')
        cls.private_corpus = Corpus.objects.create(name='private', public=False)

    def test_element_destroy_verified_user(self):
        response = self.client.delete(reverse('api:element-retrieve', kwargs={'pk': str(self.vol.id)}))
        self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)

    def test_element_destroy_acl(self):
        self.private_corpus.corpus_right.create(user_id=self.user.id, can_write=True, can_admin=False)
        self.client.force_login(self.user)
        castle_story = self.private_corpus.elements.create(
            type=self.volume_type,
            name='Castle story'
        )
        response = self.client.delete(reverse('api:element-retrieve', kwargs={'pk': str(castle_story.id)}))
        self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
        self.assertDictEqual(
            response.json(),
            {'detail': 'You do not have admin access to this element.'}
        )

    def test_element_destroy(self):
        self.client.force_login(self.user)
        castle_story = self.corpus.elements.create(
            type=self.volume_type,
            name='Castle story'
        )
        self.assertEqual(self.corpus.elements.filter(id=castle_story.id).exists(), True)
        response = self.client.delete(reverse('api:element-retrieve', kwargs={'pk': str(castle_story.id)}))
        self.assertEqual(response.status_code, status.HTTP_204_NO_CONTENT)
        self.assertEqual(self.corpus.elements.filter(id=castle_story.id).exists(), False)
