# Generated by Django 2.2.13 on 2020-07-21 08:00

from django.db import migrations, models
from django.conf import settings


def group_to_bool(apps, schema_editor):
    Group = apps.get_model('auth', 'Group')
    if not Group.objects.exists():
        # Empty database
        return
    internal_group = Group.objects.get(id=settings.INTERNAL_GROUP_ID)
    internal_group.users.all().update(is_internal=True)
    internal_group.delete()


def bool_to_group(apps, schema_editor):
    Group = apps.get_model('auth', 'Group')
    User = apps.get_model('users', 'User')
    try:
        internal_group_id = settings.INTERNAL_GROUP_ID
    except AttributeError:
        internal_group_id = None

    assert isinstance(internal_group_id, int), 'settings.INTERNAL_GROUP_ID must be defined to roll users.0004 back'

    internal_group, _ = Group.objects.get_or_create(id=internal_group_id, defaults={'name': 'Internal'})
    internal_group.users.set(User.objects.filter(is_internal=True))


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0003_user_selected_elements'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='is_internal',
            field=models.BooleanField(default=False),
        ),
        migrations.RunPython(
            group_to_bool,
            reverse_code=bool_to_group,
        )
    ]
